@@ -6,7 +6,7 @@ from typing import TYPE_CHECKING
 if TYPE_CHECKING:
     from sphinx.application import Sphinx
 
-__version__ = "0.4.5"
+__version__ = "0.5.1"
 """sphinx-jupyterbook-latex version"""
 
 
@@ -14,8 +14,9 @@ def setup(app: "Sphinx") -> None:
     """The sphinx entry-point for the extension."""
 
     from .events import override_latex_config, setup_latex_transforms
-    from .nodes import HiddenCellNode, RootHeader
+    from .nodes import CellInput, CellOutput, HiddenCellNode, RootHeader
     from .transforms import (
+        CodeBlockTransforms,
         LatexRootDocTransforms,
         LatexToctreeNodeInterpret,
         ListTableOfContents,
@@ -30,9 +31,15 @@ def setup(app: "Sphinx") -> None:
 
     HiddenCellNode.add_node(app)
     RootHeader.add_node(app)
+    CellOutput.add_node(app)
+    CellInput.add_node(app)
 
     app.add_transform(LatexRootDocTransforms)
     app.add_transform(LatexToctreeNodeInterpret)
+
+    if CodeBlockTransforms.check_mystnb_dependency():
+        app.add_post_transform(CodeBlockTransforms)
+
     app.add_post_transform(ListTableOfContents)
 
     app.connect("config-inited", override_latex_config)
