@@ -29,6 +29,7 @@ def override_latex_config(app: Sphinx, config: Config) -> None:
     # only allow latex builder to access rest of the features
     config["latex_engine"] = "xelatex"
     config["latex_theme"] = "jupyterBook"
+    config["numfig"] = True
 
     latex_elements = cast(dict, config["latex_elements"])
 
@@ -54,7 +55,9 @@ def override_latex_config(app: Sphinx, config: Config) -> None:
     )
 
     # at the moment, True means list for this config
-    if (type(config["jblatex_show_tocs"]) is bool) and config["jblatex_show_tocs"]:  # type: ignore[comparison-overlap] # noqa: E501
+    if (type(config["jblatex_show_tocs"]) is bool) and config[
+        "jblatex_show_tocs"
+    ]:  # noqa: E501
         config["jblatex_show_tocs"] = "list"
 
 
@@ -67,12 +70,15 @@ def setup_latex_transforms(app: Sphinx) -> None:
         return
 
     # note: bold is a dynamically created function
-    from sphinx.util.console import bold  # type: ignore[attr-defined]
+    from sphinx.util.console import bold
 
     # decide whether we will convert top-level toctree captions to parts
-    app.env.jblatex_captions_to_parts = False  # type: ignore[attr-defined]
-    if app.config["jblatex_captions_to_parts"] is True:  # type: ignore[comparison-overlap]
+    app.env.jblatex_captions_to_parts = False
+    app.env.img_converter_ext = False
+
+    if app.config["jblatex_captions_to_parts"] is True:
         app.config["latex_toplevel_sectioning"] = "part"
+        app.config["numfig_secnum_depth"] = 2  # equation number with chapter numbers
         app.env.jblatex_captions_to_parts = True
     elif app.config["jblatex_captions_to_parts"] is None:
         # if using the sphinx-external-toc, we can look if parts are being specified
@@ -81,28 +87,36 @@ def setup_latex_transforms(app: Sphinx) -> None:
         if sitemap is not None:
             if sitemap.file_format == "jb-book" and len(sitemap.root.subtrees) > 1:
                 app.config["latex_toplevel_sectioning"] = "part"
+                app.config[
+                    "numfig_secnum_depth"
+                ] = 2  # equation number with chapter numbers
                 app.env.jblatex_captions_to_parts = True
             elif sitemap.file_format == "jb-book":
                 app.config["latex_toplevel_sectioning"] = "chapter"
             elif sitemap.file_format == "jb-article":
                 app.config["latex_toplevel_sectioning"] = "section"
 
-    logger.info(
-        bold("sphinx-jupyterbook-latex v%s:") + "engine='%s', toplevel_section='%s'",
-        __version__,
-        app.config["latex_engine"],
-        app.config["latex_toplevel_sectioning"],
-    )
-
     # Copy the class theme to the output directory.
     # note: importlib.resources is the formal method to access files within packages
     with resources.as_file(resources.files(theme).joinpath("jupyterBook.cls")) as path:
         copy_asset_file(str(path), app.outdir)
 
     # only load when myst-nb is present
-    if MystNbPostTransform.check_dependency():
+    if MystNbPostTransform.check_mystnb_dependency():
         app.add_post_transform(MystNbPostTransform)
 
     if app.config["jblatex_load_imgconverter"]:
         app.setup_extension("sphinx.ext.imgconverter")
+        app.env.img_converter_ext = "sphinx.ext.imgconverter"
+
+    logger.info(
+        bold("sphinx-jupyterbook-latex v%s:")
+        + "engine='%s', toplevel_section='%s', imgconverter='%s', show_tocs='%s'",
+        __version__,
+        app.config["latex_engine"],
+        app.config["latex_toplevel_sectioning"],
+        app.env.img_converter_ext,
+        app.config["jblatex_show_tocs"],
+    )
+
     app.add_post_transform(LatexRootDocPostTransforms)
